## Queries

```{eval-rst}
.. module:: scanpy.queries
```

```{eval-rst}
.. currentmodule:: scanpy
```

This module provides useful queries for annotation and enrichment.

```{eval-rst}
.. autosummary::
   :nosignatures:
   :toctree: ../generated/

   queries.biomart_annotations
   queries.gene_coordinates
   queries.mitochondrial_genes
   queries.enrich

```
